package imt.personnes;

import java.util.List;
import java.util.Set;
import java.util.concurrent.atomic.AtomicInteger;

import imt.ingredients.Plat;
import lombok.AccessLevel;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.ToString;

@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
@Data
public class Chef extends Person {
	@Getter(value = AccessLevel.NONE)
	private final AtomicInteger victoires;
	private final Specialite specialite;
	private final Set<Plat> plats;

	public Chef(int id, String nom, String prenom, String telephone, Genre genre, int victoires, Specialite specialite,
			Set<Plat> plats) {
		super(id, nom, prenom, telephone, genre);
		this.victoires = new AtomicInteger(victoires);
		this.specialite = specialite;
		this.plats = plats;
	}

	public List<Plat> getPlatsParCalories() {
		return plats.stream()
			.sorted((left, right) -> {
				return Integer.valueOf(left.getCalories()).compareTo(Integer.valueOf(right.getCalories()));
			}).toList();
	}

	public int getEtoiles() {
		int victoires = this.victoires.intValue();
		if (victoires < 1) {
			return 0;
		} else if (victoires < 3) {
			return 1;
		} else if (victoires < 5) {
			return 2;
		} else {
			return 3;
		}
	}
}
